$OpenBSD: patch-src_rrd_xport_c,v 1.1 2004/06/08 20:21:24 danh Exp $
--- src/rrd_xport.c.orig	2004-04-06 17:38:15.000000000 -0400
+++ src/rrd_xport.c	2004-06-08 13:42:26.000000000 -0400
@@ -77,7 +77,7 @@ rrd_xport(int argc, char **argv, int *xs
     im.prt_c = 0;
     im.gdes_c = 0;
     im.gdes = NULL;
-    im.imgformat = IF_GIF; /* we default to GIF output */
+    im.imgformat = IF_PNG; /* we default to PNG output */
 
     while (1){
 	static struct option long_options[] =
